"""
scaffoldgraphnew tests.utils
"""

from .. import mock_sdf, mock_sdf_2
